__id__: valente_and_valente_2020_case_7

__Perte__: de transmission, asymétrique

__Basé sur__: case #7 de Valente, M., & Valente, M. (Eds.). (2020). Adult audiology casebook (Second edition). Thieme.

